<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Environnement live détecté. Choisissez la partition racine du système que vous souhaitez modifier (seules les partitions Linux sont affichées)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Utiliser une interface simple de menu sans sous-menus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Utiliser menus plats (pas de sous-menus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Démarrer sur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Régler sur « 0 » pour démarrer immédiatement sans afficher le menu, ou sur « -1 » pour attendre indéfiniment</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Durée du menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Paramètres du noyau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>En activant cette option, l’entrée choisie depuis le menu de démarrage grub sera sauvegardée et activée par défaut pour les prochains démarrages</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Activer la sauvegarde du dernier choix de démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Gérer les options de démarrage UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Arrière-plan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Activer le thème</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Écran d’accueil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Très détaillé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Détaillé (réglage par défaut)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Limité</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Afficher le journal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Afficher l’aide </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Still running</source>
        <translation>Opération toujours en cours</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Set timeout</source>
        <translation>Définir un délai d’attente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Timeout in seconds:</source>
        <translation>Délai d’attente en secondes&#xa0;:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <location filename="../mainwindow.cpp" line="618"/>
        <location filename="../mainwindow.cpp" line="1436"/>
        <source>Timeout: %1 seconds</source>
        <translation>Délai d’attente&#xa0;: %1 secondes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <location filename="../mainwindow.cpp" line="620"/>
        <location filename="../mainwindow.cpp" line="1435"/>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>Boot Next: %1</source>
        <translation>Élément sélectionné sera le paramètre par défaut, une seule fois pour le prochain démarrage&#xa0;: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Removal confirmation</source>
        <translation>Confirmer l’éjection</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Êtes-vous sûr de vouloir supprimer cette entrée de démarrage&#xa0;?
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>Select EFI file</source>
        <translation>Choisir le fichier EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>Fichiers EFI (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <location filename="../mainwindow.cpp" line="433"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <location filename="../mainwindow.cpp" line="527"/>
        <location filename="../mainwindow.cpp" line="561"/>
        <location filename="../mainwindow.cpp" line="603"/>
        <location filename="../mainwindow.cpp" line="703"/>
        <location filename="../mainwindow.cpp" line="792"/>
        <location filename="../mainwindow.cpp" line="1636"/>
        <location filename="../mainwindow.cpp" line="1649"/>
        <location filename="../mainwindow.cpp" line="1655"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Impossible de trouver la source du point de montage pour %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Set name</source>
        <translation>Définir le nom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Entrez le nom de l’entrée du menu UEFI&#xa0;:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Un problème est survenu, il n’a pas été possible d’ajouter l’entrée.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installation de l’écran d’amorçage, veuillez patienter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Updating sources</source>
        <translation>Mise-à-jour des sources</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Could not install the bootsplash.</source>
        <translation>L’écran d’amorçage n’a pas pu être installé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Failed to get UEFI boot entries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Boot Current: %1</source>
        <translation>Démarrage en cours&#xa0;: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="703"/>
        <source>Could not create a temporary folder</source>
        <translation>Impossible de créer un dossier temporaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>Cannot continue</source>
        <translation>Impossible de continuer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Impossible de créer environnement chroot, impossible de modifier les options de démarrage. Sortie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="792"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Un problème est survenu, impossible de sauvegarder l’ordre de démarrage.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1078"/>
        <location filename="../mainwindow.cpp" line="1556"/>
        <source>Updating configuration, please wait</source>
        <translation>Mise-à-jour de la configuration, veuillez patienter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1149"/>
        <source>Updating initramfs...</source>
        <translation>Mise à jour d’initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1163"/>
        <location filename="../mainwindow.cpp" line="1571"/>
        <source>Updating grub...</source>
        <translation>Mise à jour de grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1188"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1189"/>
        <source>Version: </source>
        <translation>Version&#xa0;: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programme pour définir les options de démarrage courantes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1193"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1194"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1215"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1225"/>
        <location filename="../mainwindow.cpp" line="1533"/>
        <source>Running in a Virtual Machine</source>
        <translation>Lancer dans une machine virtuelle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1226"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Votre système actuel fonctionne dans une Machine Virtuelle,
L’écran d’amorçage Plymouth fonctionnera de façon restreinte, vous ne pourrez pas non plus prévisualiser le thème</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Plymouth packages not installed</source>
        <translation>Les paquets pour Plymouth ne sont pas installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1234"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Les paquets Plymouth ne sont pas installés actuellement.
Voulez-vous les installer&#xa0;?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1260"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Images (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Log not found</source>
        <translation>Log introuvable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Could not find log at </source>
        <translation>Impossible de trouver le journal dans </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1409"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>Éditer les entrées de démarrage UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Vous pouvez utiliser les boutons Haut/Bas, ou faire glisser et déposer les éléments pour changer l’ordre de démarrage.
- Les éléments sont listés dans l’ordre de démarrage.
- Les lignes grisées sont inactives.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1423"/>
        <location filename="../mainwindow.cpp" line="1471"/>
        <source>Set ac&amp;tive</source>
        <translation>Ac&amp;tiver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>&amp;Add entry</source>
        <translation>&amp;Ajouter une entrée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1425"/>
        <source>Boot &amp;next</source>
        <translation>Éléme&amp;nt sélectionné sera le paramètre par défaut, une seule fois pour le prochain démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1636"/>
        <source>Could not retrieve UUID for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1644"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Entrer le mot de passe pour déverrouiller la partition chiffrée %1 :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1649"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1655"/>
        <source>Could not open %1 LUKS container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <location filename="../mainwindow.cpp" line="1426"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Un processus est toujours en cours. Voulez-vous vraiment arrêter&#xa0;?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Live System Detected</source>
        <translation>Détection d’un système Live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Vous utilisez actuellement un système Live. Souhaitez-vous modifier les options de démarrage pour le système Live ou pour un système installé&#xa0;?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Live System</source>
        <translation>Système Live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Installed System</source>
        <translation>Système installé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Failed to update package sources.</source>
        <translation>Impossible de mettre à jour les sources du paquet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>Installing packages:</source>
        <translation>Installation des paquets&#xa0;:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Bootsplash a été installé correctement.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Failed to create temporary file.</source>
        <translation>Impossible de créer un fichier temporaire.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1171"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Vous êtes actuellement en mode Live avec l’option «&#xa0;toram&#xa0;». N’oubliez pas de sauvegarder le fichier de persistance ou de remasteriser, sinon toutes les modifications apportées seront perdues.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1173"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Vos modifications ont été appliquées avec succès.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1174"/>
        <source>Operation Complete</source>
        <translation>L’opération est terminée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1259"/>
        <source>Select image to display in bootloader</source>
        <translation>Choisir l’image à afficher pour le chargeur de démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1383"/>
        <source>Boot Log</source>
        <translation>Journal de démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1427"/>
        <source>Move &amp;down</source>
        <translation>Descen&amp;dre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1428"/>
        <source>&amp;Remove entry</source>
        <translation>&amp;Supprimer l’entrée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1429"/>
        <source>Re&amp;set next</source>
        <translation>Ré&amp;initialiser l’entrée par défaut en cours pour le prochain démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1430"/>
        <source>Change &amp;timeout</source>
        <translation>M&amp;odifier le délai d’attente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Move &amp;up</source>
        <translation>Mont&amp;er</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1435"/>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>not set, will boot using list order</source>
        <translation>non défini, le démarrage se fera dans l’ordre de la liste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1468"/>
        <source>Set &amp;inactive</source>
        <translation>Désa&amp;ctiver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1522"/>
        <source>Needs reboot</source>
        <translation>Redémarrage requis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1523"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth vient d’être installé, vous devrez probablement redémarrer avant de pouvoir afficher les aperçus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Click to select theme</source>
        <translation>Cliquez pour sélectionner le thème</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1603"/>
        <source>Select GRUB theme</source>
        <translation>Choisir le thème de GRUB</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programme pour définir les options de démarrage courantes</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="56"/>
        <location filename="../about.cpp" line="65"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur normal pour utiliser ce programme.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>Vous devez exécuter ce programme avec un accès administrateur.</translation>
    </message>
</context>
</TS>
